# Tai-Chi Engine Structure

> "太極生兩儀 兩儀生四象" -- 《易經》

> Tai-Chi Engine has 4 phases, that builds everything around dataframe.:

* [Enrich](enrich) - The 1st phase. Add more column to dataframe.
* [Quantify](quantify) - The 2nd phase. Pick your columns for a deep learning task, and how you transfer data into tensors(hyper dimentional matrix of numbers as model likes).
* [Modeling](model) - 3rd phase. Shopping your model detail, off-the-shelfly
* Training - 4th phase. Train your AI mode.